import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import { createVNode as _createVNode } from "vue";
import { defineComponent } from 'vue-demi';
import isEqual from 'lodash/isEqual';
var BaseChart = defineComponent({
  inheritAttrs: false,
  name: 'BaseChart',
  computed: {
    attrConfig: function attrConfig() {
      return this.$attrs;
    },
    chartData: function chartData() {
      var data = this.attrConfig.data;
      return data || [];
    },
    chartConfig: function chartConfig() {
      var _this$attrConfig = this.attrConfig,
          chart = _this$attrConfig.chart,
          chartRef = _this$attrConfig.chartRef,
          data = _this$attrConfig.data,
          className = _this$attrConfig.class,
          style = _this$attrConfig.style,
          config = _objectWithoutProperties(_this$attrConfig, ["chart", "chartRef", "data", "class", "style"]);

      return config;
    }
  },
  mounted: function mounted() {
    var chartRef = this.$attrs.chartRef;
    var Chart = this.attrConfig.chart;
    var plot = new Chart(this.$el, _objectSpread({
      data: this.chartData
    }, this.chartConfig));
    plot.render();

    if (chartRef) {
      chartRef.value = plot;
    }

    this.plot = plot;
  },
  beforeUnmount: function beforeUnmount() {
    /* istanbul ignore else */
    if (this.plot) {
      this.plot.destroy();
    }
  },
  watch: {
    chartData: function chartData(data, oldData) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!oldData.length) {
          this.plot.update(_objectSpread({
            data: data
          }, this.chartConfig));
          this.plot.render();
        } else {
          this.plot.changeData(data);
        }
      }
    },
    chartConfig: function chartConfig(config, oldConfig) {
      /* istanbul ignore else */
      if (this.plot) {
        if (!isEqual(config, oldConfig)) {
          this.plot.update(_objectSpread({
            data: this.chartData
          }, config));
        }
      }
    }
  },
  render: function render() {
    return _createVNode("div", {
      "class": this.attrConfig.class,
      "style": this.attrConfig.style
    }, null);
  }
});
export default BaseChart;